<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>AppMain</name>
    <message>
        <location filename="src/common/vlcpalyer.cpp" line="54"/>
        <location filename="src/main.cpp" line="94"/>
        <location filename="src/main.cpp" line="95"/>
        <location filename="src/views/vnotemainwindow.cpp" line="615"/>
        <source>Voice Notes</source>
        <translation>Hlasové poznámky</translation>
    </message>
    <message>
        <location filename="src/main.cpp" line="96"/>
        <source>Voice Notes is a lightweight memo tool to make text notes and voice recordings.</source>
        <translation>Hlasové poznámky jsou nástrojem pro pořizování textových poznámek a hlasových nahrávek.</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="616"/>
        <source>Recordings not saved</source>
        <translation>Nahrávky neuloženy</translation>
    </message>
</context>
<context>
    <name>DefaultName</name>
    <message>
        <location filename="src/db/vnotefolderoper.cpp" line="245"/>
        <source>Notebook</source>
        <translation>Zápisník</translation>
    </message>
    <message>
        <location filename="src/db/vnoteitemoper.cpp" line="228"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="src/db/vnoteitemoper.cpp" line="243"/>
        <location filename="src/importolddata/olddbvisistors.cpp" line="154"/>
        <source>Voice</source>
        <translation>Hlas</translation>
    </message>
</context>
<context>
    <name>DetailPage</name>
    <message>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="213"/>
        <source>%1 notes selected</source>
        <translation>Vybráno %1 poznámek</translation>
    </message>
</context>
<context>
    <name>FolderSelectDialog</name>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="217"/>
        <source>Move Notes</source>
        <translation>Přesunout poznámky</translation>
    </message>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="244"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="245"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Potvrdit</translation>
    </message>
</context>
<context>
    <name>HomePage</name>
    <message>
        <location filename="src/views/homepage.cpp" line="48"/>
        <source>Create Notebook</source>
        <translation>Vytvořit zápisník</translation>
    </message>
    <message>
        <location filename="src/views/homepage.cpp" line="60"/>
        <source>Create a notebook to start recording voice and making notes</source>
        <translation>Vytvořit zápisník pro zahájení nahrávání hlasu a dělání poznámek</translation>
    </message>
</context>
<context>
    <name>LeftView</name>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="380"/>
        <location filename="src/dialog/folderselectdialog.cpp" line="394"/>
        <source>Move %1 notes (%2, ...) to:</source>
        <translation>Přesunout %1 poznámek (%2, …) do:</translation>
    </message>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="381"/>
        <location filename="src/dialog/folderselectdialog.cpp" line="384"/>
        <location filename="src/dialog/folderselectdialog.cpp" line="392"/>
        <source>Move the note &quot;%1&quot; to:</source>
        <translation>Přesunout poznámku „%1“ do:</translation>
    </message>
</context>
<context>
    <name>MiddleView</name>
    <message>
        <location filename="src/views/middleview.cpp" line="303"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="src/views/middleview.cpp" line="1057"/>
        <source>No search results</source>
        <translation>Nic nenalezeno</translation>
    </message>
</context>
<context>
    <name>MiddleViewDelegate</name>
    <message>
        <location filename="src/views/middleviewdelegate.cpp" line="442"/>
        <source>Sticky Notes</source>
        <translation>Lepítka s poznámkami</translation>
    </message>
</context>
<context>
    <name>NoteDetailContextMenu</name>
    <message>
        <location filename="src/common/actionmanager.cpp" line="276"/>
        <source>Save as MP3</source>
        <translation>Uložit jako MP3</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="277"/>
        <source>Voice to Text</source>
        <translation>Hlas na text</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="278"/>
        <location filename="src/common/actionmanager.cpp" line="305"/>
        <location filename="src/common/actionmanager.cpp" line="331"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="279"/>
        <location filename="src/common/actionmanager.cpp" line="306"/>
        <location filename="src/common/actionmanager.cpp" line="332"/>
        <source>Select all</source>
        <translation>Vybrat vše</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="280"/>
        <location filename="src/common/actionmanager.cpp" line="307"/>
        <location filename="src/common/actionmanager.cpp" line="333"/>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="281"/>
        <location filename="src/common/actionmanager.cpp" line="308"/>
        <location filename="src/common/actionmanager.cpp" line="334"/>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="282"/>
        <location filename="src/common/actionmanager.cpp" line="309"/>
        <location filename="src/common/actionmanager.cpp" line="335"/>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="304"/>
        <source>View</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="310"/>
        <source>Save as</source>
        <translation>Uložit jako</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="336"/>
        <source>Text to Speech</source>
        <translation>Text na řeč</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="337"/>
        <source>Stop reading</source>
        <translation>Přestat předčítat</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="338"/>
        <source>Speech to Text</source>
        <translation>Řeč na text</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="339"/>
        <source>Translate</source>
        <translation>Přeložit</translation>
    </message>
</context>
<context>
    <name>NotebookContextMenu</name>
    <message>
        <location filename="src/common/actionmanager.cpp" line="220"/>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="221"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="222"/>
        <source>New note</source>
        <translation>Nová poznámka</translation>
    </message>
</context>
<context>
    <name>NotesContextMenu</name>
    <message>
        <location filename="src/common/actionmanager.cpp" line="195"/>
        <source>Save as HTML</source>
        <translation>Uložit jako HTML</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="196"/>
        <source>Save as TXT</source>
        <translation>Uložit jako TXT</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="200"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="342"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="353"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="359"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="361"/>
        <source>Save note</source>
        <translation>Uložit poznámku</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="240"/>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="242"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="336"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="345"/>
        <source>Move</source>
        <translation>Přesunout</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="243"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="338"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="344"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="245"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="343"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="354"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="366"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="368"/>
        <source>Save voice recording</source>
        <translation>Uložit hlasovou nahrávku</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="246"/>
        <source>New note</source>
        <translation>Nová poznámka</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1258"/>
        <source>Unstick</source>
        <translation>Odlepit</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1260"/>
        <source>Sticky on Top</source>
        <translation>Zůstává na začátku</translation>
    </message>
</context>
<context>
    <name>Setting</name>
    <message>
        <location filename="src/common/setting.cpp" line="39"/>
        <source>Basic</source>
        <translation>Základní</translation>
    </message>
    <message>
        <location filename="src/common/setting.cpp" line="40"/>
        <source>Audio Source</source>
        <translation>Zdroj zvuku</translation>
    </message>
    <message>
        <location filename="src/common/setting.cpp" line="41"/>
        <source>Internal</source>
        <translation>Interní</translation>
    </message>
    <message>
        <location filename="src/common/setting.cpp" line="42"/>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
</context>
<context>
    <name>Shortcuts</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="919"/>
        <source>New notebook</source>
        <translation>Nový zápisník</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="920"/>
        <source>Rename notebook</source>
        <translation>Přejmenovat zápisník</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="921"/>
        <source>Delete notebook</source>
        <translation>Smazat zápisník</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="943"/>
        <source>New note</source>
        <translation>Nová poznámka</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="944"/>
        <source>Rename note</source>
        <translation>Přejmenovat poznámku</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="945"/>
        <source>Delete note</source>
        <translation>Smazat poznámku</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="946"/>
        <source>Play/Pause</source>
        <translation>Přehrát/pozastavit</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="947"/>
        <source>Record voice</source>
        <translation>Nahrát hlas</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="948"/>
        <source>Save note</source>
        <translation>Uložit poznámku</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="949"/>
        <source>Save recordings</source>
        <translation>Uložit nahrávky</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="969"/>
        <source>Select all</source>
        <translation>Vybrat vše</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="970"/>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="971"/>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="972"/>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="973"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="996"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="997"/>
        <source>Display shortcuts</source>
        <translation>Zobrazit zkratky</translation>
    </message>
</context>
<context>
    <name>ShortcutsGroups</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="925"/>
        <source>Notebooks</source>
        <translation>Zápisníky</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="953"/>
        <source>Notes</source>
        <translation>Poznámky</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="977"/>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1001"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
</context>
<context>
    <name>SplashView</name>
    <message>
        <location filename="src/views/splashview.cpp" line="46"/>
        <source>Loading...</source>
        <translation>Načítání…</translation>
    </message>
</context>
<context>
    <name>TitleBar</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="371"/>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1889"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1890"/>
        <source>Privacy Policy</source>
        <translation>Zásady ochrany soukromí</translation>
    </message>
</context>
<context>
    <name>UpgradeView</name>
    <message>
        <location filename="src/importolddata/upgradeview.cpp" line="50"/>
        <source>Importing notes from the old version, please wait...</source>
        <translation>Import poznámek ze staré verze – čekejte prosím…</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="src/common/utils.cpp" line="56"/>
        <source>1 min ago</source>
        <translation>Před 1 minutou</translation>
    </message>
    <message>
        <location filename="src/common/utils.cpp" line="58"/>
        <source>%1 mins ago</source>
        <translation>Před %1 minutami</translation>
    </message>
    <message>
        <location filename="src/common/utils.cpp" line="64"/>
        <source>Yesterday</source>
        <translation>Včera</translation>
    </message>
</context>
<context>
    <name>VNoteErrorMessage</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="881"/>
        <source>The voice conversion failed due to the poor network connection, please have a check</source>
        <translation>Hlas se nepodařilo převést kvůli špatnému síťovému spojení – zkontrolujte ho</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="885"/>
        <source>Voice to text conversion failed</source>
        <translation>Převod hlasu na text se nezdařil</translation>
    </message>
</context>
<context>
    <name>VNoteMainWindow</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="470"/>
        <source>Create Notebook</source>
        <translation>Vytvořit zápisník</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialog</name>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="53"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="132"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="133"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Potvrdit</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="136"/>
        <source>Are you sure you want to delete this notebook?
All notes in it will be deleted</source>
        <translation>Opravdu chcete tento zápisník smazat?
Veškeré poznámky v něm budou smazány</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="139"/>
        <source>Do you want to stop the current recording?</source>
        <translation>Chcete právě probíhající nahrávání zastavit?</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="143"/>
        <source>Are you sure you want to delete the selected %1 notes?</source>
        <translation>Opravdu chcete smazat označených %1 poznámek?</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="145"/>
        <source>Are you sure you want to delete this note?</source>
        <translation>Opravdu chcete tuto poznámku smazat?</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="149"/>
        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
        <translation>Tuto hlasovou poznámku nelze převést, protože poznámky delší než 20 minut nejsou v současnosti podporovány.</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="153"/>
        <source>Converting a voice note now. Do you want to stop it?</source>
        <translation>Nyní se probíhá převod hlasové poznámky. Chcete ho zastavit?</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="156"/>
        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
        <translation>Příliš tichá vstupní hlasitost může mít za následek špatné nahrávky. Chcete pokračovat?</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="159"/>
        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
        <translation>Sestříhané nahrávky a převedený text nebudou vloženy. Chcete pokračovat?</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="162"/>
        <source>Save failed</source>
        <translation>Uložení se nezdařilo</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="166"/>
        <source>You do not have permission to save files there</source>
        <translation>Nemáte oprávnění ukládat tam soubory</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="170"/>
        <source>The voice note has been deleted</source>
        <translation>Hlasová poznámka byla smazána</translation>
    </message>
</context>
<context>
    <name>VNoteRecordBar</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1736"/>
        <source>Your audio recording device does not work.</source>
        <translation>Zařízení pro nahrávání zvuku nefunguje.</translation>
    </message>
    <message>
        <location filename="src/views/vnoterecordbar.cpp" line="249"/>
        <source>No recording device detected</source>
        <translation>Nezjištěno žádné zařízení pro nahrávání zvuku</translation>
    </message>
</context>
<context>
    <name>VoiceNoteItem</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1679"/>
        <source>Converting voice to text</source>
        <translation>Převádění hlasu na text</translation>
    </message>
</context>
<context>
    <name>web</name>
    <message>
        <location filename="src/common/jscontent.cpp" line="141"/>
        <source>Font</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="142"/>
        <source>Font size</source>
        <translation>Velikost písma</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="143"/>
        <source>Font color</source>
        <translation>Barva písma</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="144"/>
        <source>Text highlight color</source>
        <translation>Barva zvýraznění písma</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="145"/>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="146"/>
        <source>Italic</source>
        <translation>Skloněné</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="147"/>
        <source>Underline</source>
        <translation>Podtržené</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="148"/>
        <source>Strikethrough</source>
        <translation>Přeškrnuté</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="149"/>
        <source>Bullets</source>
        <translation>Odrážky</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="150"/>
        <source>Numbering</source>
        <translation>Číslování</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="151"/>
        <source>More colors</source>
        <translation>Další barvy</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="152"/>
        <source>Recent</source>
        <translation>Nedávné</translation>
    </message>
</context>
</TS>